# Başlamak!

Rapunzel'e hoş geldiniz, Python ve R için modern bir geliştirme ortamı. İşte birkaç kullanışlı klavye kısayolu.


## Proje klasörleri ve dosyalarıyla çalışma

- [`Ctrl+Shift+O`: Proje klasörünü aç](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: Proje klasörlerinden dosya aç](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: Boş belge oluştur](opensesame://event.ide_new_file)


## İşleri hızlıca yapma

- [`Ctrl+Shift+P`: Komut paletini etkinleştir](opensesame://event.command_palette_activate)
- `Ctrl+R`: Fonksiyona veya sınıfa atla


## Kod çalıştırma

- `F5`: Projeyi veya dosyayı çalıştır
- `F9`: Seçimi, hücreyi veya mevcut satırı çalıştır